SpreadsheetTable class

A customizable and interactive spreadsheet-like table widget.

Inheritance

Constructors

SpreadsheetTable({Key? key, required List<SpreadsheetRow> initialData, required List<String> headers, ValueChanged<List<SpreadsheetRow>>? onDataChanged, ValueChanged<SpreadsheetRow>? onRowDataChanged, VoidCallback? onNewRowAdded, ValueChanged<SpreadsheetRow>? onRowDismissed, SpreadsheetButtonBuilder? leadingButtonBuilder, SpreadsheetButtonBuilder? trailingButtonBuilder, EdgeInsetsGeometry cellContentPadding = const EdgeInsets.symmetric(horizontal: 10.0, vertical: 8.0), bool zebraStripe = false, List<Color> stripeColors = const [Colors.white, Color(0xFFF5F5F5)], bool autoLeadingSN = false, Map<String, TextAlign> columnAlignments = const {}, Map<String, List<String>> dropdownOptions = const {}, Map<String, CellValidator> validators = const {}})
const

Properties

autoLeadingSN bool
Specifies whether to use automatic Symbol Number(SN) or not. If true adds SN as a header and manages values of SN automatically
final
cellContentPadding EdgeInsetsGeometry
Content Padding for individual Table cell
final
columnAlignments Map<String, TextAlign>
Alignments for Column Headers
final
Specifies which Columns has to have DropDownMenu
final
hashCode int
The hash code for this object.
no setterinherited
headers List<String>
Table Headers
final
initialData List<SpreadsheetRow>
Initial Data for Table. Example:
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingButtonBuilder SpreadsheetButtonBuilder?
Method for building leading Button
final
onDataChanged ValueChanged<List<SpreadsheetRow>>?
This method is called on data Changed on any row
final
onNewRowAdded VoidCallback?
This method is called when new row is added
final
onRowDataChanged ValueChanged<SpreadsheetRow>?
This method is called when current row data is changed
final
onRowDismissed ValueChanged<SpreadsheetRow>?
This method is called when row is dismissed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripeColors List<Color>
Colors for zebra Stripe. Specify Just two Colors
final
trailingButtonBuilder SpreadsheetButtonBuilder?
Method for building trailing Button
final
validators Map<String, CellValidator>
Validators for various Columns. Displays SnackBar
final
zebraStripe bool
Specifies whether to use zebraStripes or not
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SpreadsheetTableState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited