autoLeadingSN property
Specifies whether to use automatic Symbol Number(SN) or not. If true adds SN as a header and manages values of SN automatically
Implementation
final bool autoLeadingSN;
Specifies whether to use automatic Symbol Number(SN) or not. If true adds SN as a header and manages values of SN automatically
final bool autoLeadingSN;