onRowDataChanged property
This method is called when current row data is changed
Implementation
final ValueChanged<SpreadsheetRow>? onRowDataChanged;
This method is called when current row data is changed
final ValueChanged<SpreadsheetRow>? onRowDataChanged;